# vim: set sw=4 ts=4 et nu:
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/


Name:           mpd
Version:        0.19.17
Release:        1.2
License:        GPL-3.0+
Summary:        Music Player Daemon
Url:            http://www.musicpd.org/
Group:          Productivity/Multimedia/Sound/Players
Source:         http://www.musicpd.org/download/mpd/0.19/mpd-%{version}.tar.xz
Source1:        %{name}.init
Source2:        README.%{name}
Source3:        mpd-user.conf
Source4:        mpd.service
# PATCH-FEATURE-OPENSUSE mpd-mpdconf_suse.patch --
Patch0:         %{name}-mpdconf_suse.patch
# PATCH-FIX-OPENSUSE mpd-sndfile-vorbis.patch --
Patch2:         mpd-sndfile-vorbis.patch
BuildRequires:  alsa-devel
BuildRequires:  audiofile-devel
BuildRequires:  automake
BuildRequires:  autoconf
BuildRequires:  boost-devel >= 1.46
BuildRequires:  cdrkit-cdrtools-compat
BuildRequires:  faad2-devel
BuildRequires:  flac-devel
BuildRequires:  gcc-c++
BuildRequires:  libao-devel
BuildRequires:  libavahi-devel
BuildRequires:  libavahi-glib-devel
BuildRequires:  libcdio-devel
%if 0%{?suse_version} >= 1220
BuildRequires:  libcdio-paranoia-devel
%endif
BuildRequires:  libcue-devel
BuildRequires:  libcurl-devel
BuildRequires:  pkgconfig(libavcodec) >= 53.25
BuildRequires:  pkgconfig(libavformat) >= 53.17
BuildRequires:  pkgconfig(libavutil) >= 51.17
BuildRequires:  libmpdclient-devel
BuildRequires:  libsndfile-devel
%if 0%{?suse_version} >= 1230
BuildRequires:  pkgconfig(bzip2)
%endif
BuildRequires:  tcpd-devel
BuildRequires:  pkgconfig(glib-2.0)
%if 0%{?suse_version} > 1100
%if 0%{?suse_version} <= 1130
BuildRequires:  fluidsynth-devel
%else
BuildRequires:  libfluidsynth-devel
%endif
%endif
BuildRequires:  libicu-devel
BuildRequires:  libid3tag-devel
BuildRequires:  libjack-devel
BuildRequires:  libmad-devel
BuildRequires:  libmikmod-devel
BuildRequires:  libmms-devel
BuildRequires:  libmodplug-devel
BuildRequires:  libmp3lame-devel
BuildRequires:  libmpcdec-devel
BuildRequires:  libmpg123-devel
BuildRequires:  libogg-devel
BuildRequires:  libpulse-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libshout-devel
BuildRequires:  libtwolame-devel
BuildRequires:  libvorbis-devel
%if 0%{?suse_version} >= 1140
BuildRequires:  libyajl1-devel
%endif
BuildRequires:  openal-soft-devel
BuildRequires:  sqlite3-devel
%if 0%{?suse_version} >= 1210
BuildRequires:  systemd-devel
%endif
BuildRequires:  udev
BuildRequires:  wavpack-devel
BuildRequires:  xmlto
%if 0%{?suse_version} >= 1130
BuildRequires:  zziplib-devel
%endif
%if 0%{?suse_version} < 1130
BuildRequires:  libzziplib-devel
%endif
BuildRequires:  zip
%if 0%{?suse_version} >= 1120
BuildRequires:  libgme-devel
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A daemon for playing music (mp3, ogg vorbis, flac, and wav).  Music is
played through the server's audio device.  The daemon stores info
about all available music, and this info can be easily searched and
retrieved.  Player control, info retrieval, and playlist management
can all be managed remotely. There a bunch of clients to control mpd:
for Gnome, KDE, console and Apache (PHP).

Please read README.mpd how to configure it.

%prep
%setup -q
%patch0 -p1
%patch2 -p1

%build
export CXXFLAGS="%{optflags} --std=gnu++11"
#Need to run as makefile.in built with later version of automake. 
[ -x autogen.sh ] && NOCONFIGURE=1 ./autogen.sh
%configure \
        --enable-debug \
        --enable-ao \
        --enable-audiofile \
        --enable-bzip2 \
        --enable-cdio-paranoia \
        --enable-curl \
        --enable-ffmpeg \
        --enable-flac \
%if 0%{?suse_version} > 1100
        --enable-fluidsynth \
%endif
        --enable-httpd-output \
        --enable-id3 \
        --enable-iso9660 \
        --enable-jack \
	--enable-lame-encoder \
	--enable-libmpdclient \
        --enable-lsr \
        --enable-mikmod \
        --enable-mms \
        --enable-openal \
        --enable-pulse \
        --enable-recorder-output \
        --enable-shout \
        --enable-sqlite \
%if 0%{?suse_version} >= 1210
        --enable-systemd-daemon \
%endif
        --enable-vorbis \
        --enable-vorbis-encoder \
        --enable-wave-encoder \
        --enable-wavpack \
        --enable-zzip \
	--with-boost=yes \
	--disable-libwrap \
	--disable-soxr \
	--disable-smbclient \
	--disable-nfs \
	--disable-upnp \
	--disable-adplug \
	--disable-opus \
	--disable-mpc \
	--disable-sidplay \
	--disable-wildmidi \
	--disable-shine-encoder \
	--disable-roar
make %{?_smp_mflags}

%install
%makeinstall docdir=%{_docdir}/%{name}
# missing dirs
install -d \
        %{buildroot}/var/lib/mpd/playlists \
        %{buildroot}%{_sbindir}
# additional docs
install -m 0644 %{SOURCE2} \
        AUTHORS COPYING NEWS README \
        %{buildroot}%{_docdir}/%{name}/
# copy example mpd.conf
install -Dm0644 %{buildroot}%{_docdir}/%{name}/mpdconf.example %{buildroot}/etc/mpd.conf
cp -a "%{SOURCE3}" "%{buildroot}%{_docdir}/%{name}/"
%if 0%{?suse_version} >= 1210
# do not use the mpd-supplied service file
install -Dm0644 %{S:4} %{buildroot}/%{_unitdir}/%{name}.service
pushd %{buildroot}%{_sbindir}
ln -s service rcmpd
%else
# init scripts
install -Dm0755 %{SOURCE1} %{buildroot}/etc/init.d/mpd
ln -s -f ../../etc/init.d/mpd %{buildroot}%{_sbindir}/rcmpd
%endif

%pre
# add mpd user only when installing first time
if [ "$1" = "1" ]; then
    useradd -G audio -s /bin/false -r -c "mpd user to run Music Player Daemon" \
        -d "%{_localstatedir}/lib/%{name}" mpd &>/dev/null; true
fi
%if 0%{?suse_version} >= 1210
%service_add_pre mpd.service
%endif

%post
%if 0%{?suse_version} >= 1210
%service_add_post mpd.service
%else
%{fillup_and_insserv -f mpd}
%endif

%preun
%if 0%{?suse_version} >= 1210
%service_del_preun mpd.service
%else
%stop_on_removal mpd
%endif

%postun
# remove mpd user when uninstalling package
if [ "$1" = "0" ]; then
   userdel mpd &> /dev/null; true
fi
%if 0%{?suse_version} >= 1210
%service_del_postun mpd.service
%else
%restart_on_update mpd
%insserv_cleanup
%endif

%files
%defattr(-,root,root)
%config(noreplace) /etc/%{name}.conf
%{_bindir}/%{name}
%{_sbindir}/rcmpd
%attr(0755,mpd,audio) %{_localstatedir}/lib/%{name}
%{_mandir}/man1/%{name}.1*
%{_mandir}/man5/%{name}.conf.5*
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}
%if 0%{?suse_version} >= 1210
%{_unitdir}/%{name}.service
%else
%attr(0755,root,root) /etc/init.d/%{name}
%endif

%changelog
* Fri Jul 29 2016 olaf@aepfle.de
- Update to ver 0.19.17 (2016/07/09)
  * decoder
  - flac: fix assertion failure while seeking
  - flac: fix stream duration indicator
  - fix seek problems in several plugins
  * fix spurious seek error "Failed to allocate silence buffer"
  * replay gain: fix "replay_gain_handler mixer" setting
  * DSD: use 0x69 as silence pattern
  * fix use-after-free bug on "close" and "kill"
  ver 0.19.16 (2016/06/13)
  * faster seeking
  * fix system include path order
  * add missing DocBook file to tarball
  ver 0.19.15 (2016/04/30)
  * decoder
  - ffmpeg: support FFmpeg 3.0
  - ffmpeg: use as fallback instead of "mad" if no plugin matches
  - opus: support bigger OpusTags packets
  * fix more build failures on non-glibc builds due to constexpr Mutex
  * fix build failure due to missing include
  * fix unit test on Alpha
  ver 0.19.14 (2016/03/18)
  * decoder
  - dsdiff: fix off-by-one buffer overflow
  - opus: limit tag size to 64 kB
  * archive
  - iso9660: fix buffer overflow
  * fix quadratic runtime bug in the tag pool
  * fix build failures on non-glibc builds due to constexpr Mutex
  ver 0.19.13 (2016/02/23)
  * tags
  - aiff, riff: fix ID3 chunk padding
  * decoder
  - ffmpeg: support the TAK codec
  * fix disappearing duration of remote songs during playback
  * initialize supplementary groups with glibc 2.19+
  ver 0.19.12 (2015/12/15)
  * fix assertion failure on malformed UTF-8 tag
  * fix build failure on non-Linux systems
  * fix LimitRTTIME in systemd unit file
  ver 0.19.11 (2015/10/27)
  * tags
  - ape: fix buffer overflow
  * decoder
  - ffmpeg: fix crash due to wrong avio_alloc_context() call
  - gme: don't loop forever, fall back to GME's default play length
  * encoder
  - flac: fix crash with 32 bit playback
  * mixer
  - fix mixer lag after enabling/disabling output
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Thu Aug 27 2015 Mathias.Homann@opensuse.org
- Update to ver 0.19.10 (2015/06/21)
  * input
  - curl: fix deadlock on small responses
  - smbclient: fix DFF playback
  * decoder
  - ffmpeg: improve seeking accuracy
  - fix stuck stream tags
  * encoder
  - opus: fix bogus granulepos
  * output
  - fix failure to open device right after booting
  * neighbor
  - nfs: fix deadlock when connecting
  * fix "single" mode breakage due to queue edits
* Wed Mar  4 2015 joerg.lorenzen@ki.tng.de
-Update to version 0.19.9:
  + Decoder:
  * dsdiff, dsf: raise ID3 tag limit to 1 MB.
  + Playlist:
  * Fix loading duplicate tag types from state file.
  + Despotify:
  * Remove defunct plugin.
  + Fix clock integer overflow on OS X.
  + Fix gcc 5.0 warnings.
  + Fix build failure with uClibc.
  + Fix build failure on non-POSIX operating systems.
  + Fix dependency issue on parallel Android build.
  + Fix database/state file saving on Windows.
- Changes from version 0.19.8:
  + Input:
  * curl: Fix bug after rewinding from end-of-file.
  * mms: Reduce delay at the beginning of playback.
  + Decoder:
  * dsdiff, dsf: Allow ID3 tags larger than 4 kB.
  * ffmpeg: Support interleaved floating point.
  + Fix clang 3.6 warnings.
  + Fix build failure on NetBSD.
- Changes from version 0.19.7:
  + Input:
  * nfs: Fix crash while canceling a failing file open operation.
  * nfs: Fix memory leak on connection failure.
  * nfs: Fix reconnect after mount failure.
  * nfs: Implement mount timeout (60 seconds).
  + Storage:
  * nfs: Implement I/O timeout (60 seconds).
  + Playlist:
  * embcue: Fix filename suffix detection.
  * Don't skip non-existent songs in "listplaylist".
  + Decoder:
  * ffmpeg: Fix time stamp underflow.
  + Fix memory allocator bug on Windows.
- Changes from version 0.19.6:
  + Decoder:
  * ffmpeg: Support FFmpeg 2.5.
  + Fix build failure with musl.
  + Android:
  * Update libFLAC to 1.3.1.
  * Update FFmpeg to 2.5.
- Changes from version 0.19.5:
  + Input:
  * nfs: Fix crash on connection failure.
  + Archive:
  * zzip: Fix crash after seeking.
  + Decoder:
  * dsdiff, dsf, opus: Fix deadlock while seeking.
  * mp4v2: Remove because of incompatible license.
* Wed Nov 26 2014 malcolmlewis@opensuse.org
- Update spec file to add lame support.
* Sat Nov 22 2014 malcolmlewis@opensuse.org
-Update to version 0.19.4:
  + Protocol:
  * Workaround for buggy clients that send "add /".
  + Decoder:
  * Ffmpeg: support opus.
  * Opus: add MIME types audio/ogg and application/ogg.
  * Fix crash on failed filename charset conversion.
  * Fix local socket detection from uid=0 (root).
- Changes from version 0.19.3:
  + Protocol:
  * Fix "(null)" result string to "list" when AlbumArtist is
    disabled.
  + Database:
  * Upnp: fix breakage due to malformed URIs.
  + Input:
  * Curl: another fix for redirected streams.
  + Decoder
  * Audiofile: fix crash while playing streams.
  * Audiofile: fix bit rate calculation.
  * Ffmpeg: support opus.
  * Opus: fix bogus duration on streams.
  * Opus: support chained streams.
  * Opus: improved error logging.
  + Fix distorted audio with soxr resampler.
- Changes from version 0.19.2:
  + Input:
  * Curl: fix redirected streams.
  + Playlist:
  * Don't allow empty playlist name.
  * M3u: don't ignore unterminated last line.
  * M3u: recognize the file suffix ".m3u8".
  + Decoder:
  * Ignore URI query string for plugin detection.
  * Faad: remove workaround for ancient libfaad2 ABI bug.
  * Ffmpeg: recognize MIME type audio/aacp.
  * Mad: fix negative replay gain values.
  + Output:
  * Fix memory leak after filter initialization error.
  * Fall back to PCM if given DSD sample rate is not supported.
  + Fix assertion failure on unsupported PCM conversion.
  + Auto-disable plugins that require GLib when --disable-glib is
    used.
- Changes from version 0.19.1:
  + Input:
  * Mms: fix deadlock bug.
  + Playlist:
  * Extm3u: fix Extended M3U detection.
  * M3u, extm3u, cue: fix truncated lines.
  + Add missing file systemd/mpd.socket to tarball.
- Changes from version 0.19:
  + Protocol:
  * new commands "addtagid", "cleartagid", "listfiles",
    "listmounts", "listneighbors", "mount", "rangeid", "unmount".
  * "lsinfo" and "readcomments" allowed for remote files.
  * "listneighbors" lists file servers on the local network.
  * "playlistadd" supports file:///.
  * "idle" with unrecognized event name fails.
  * "list" on album artist falls back to the artist tag.
  * "list" and "count" allow grouping.
  * New "search"/"find" filter "modified-since".
  * "seek*" allows fractional position.
  * Close connection after syntax error.
  + Database:
  * Proxy: forward "idle" events.
  * Proxy: forward the "update" command.
  * Proxy: copy "Last-Modified" from remote directories.
  * Simple: compress the database file using gzip.
  * Upnp: new plugin.
  * Cancel the update on shutdown.
  + Storage:
  * music_directory can point to a remote file server.
  * Nfs: new plugin.
  * Smbclient: new plugin.
  + Playlist:
  * Cue: fix bogus duration of the last track.
  * Cue: restore CUE tracks from state file.
  * Soundcloud: use https instead of http.
  * Soundcloud: add default API key.
  + Archive:
  * Read tags from songs in an archive.
  + Input:
  * Alsa: new input plugin.
  * Curl: options "verify_peer" and "verify_host".
  * Ffmpeg: update offset after seeking.
  * Ffmpeg: improved error messages.
  * Mms: non-blocking I/O.
  * Nfs: new input plugin.
  * Smbclient: new input plugin.
  + Filter
  * Volume: improved software volume dithering.
  + Decoder:
  * Vorbis, flac, opus: honor DESCRIPTION= tag in Xiph-based
    files as a comment to the song.
  * Audiofile: support scanning remote files.
  * Audiofile: log libaudiofile errors.
  * Dsdiff, dsf: report bit rate.
  * Dsdiff, dsf: implement seeking.
  * Dsf: support DSD512.
  * Dsf: support multi-channel files.
  * Dsf: fix big-endian bugs.
  * Dsf: fix noise at end of malformed file.
  * Mpg123: support ID3v2, ReplayGain and MixRamp.
  * Sndfile: support scanning remote files.
  * Sndfile: support tags "comment", "album", "track", "genre".
  * Sndfile: native floating point playback.
  * Sndfile: optimized 16 bit playback.
  * Mp4v2: support playback of MP4 files.
  + Encoder:
  * Shine: new encoder plugin.
  + Output:
  * Alsa: support native DSD playback.
  * Alsa: rename "DSD over USB" to "DoP".
  + Threads:
  * The update thread runs at "idle" priority.
  * The output thread runs at "real-time" priority.
  * Increase kernel timer slack on Linux.
  * Name each thread (for debugging).
  + Configuration:
  * Allow playlist directory without music directory.
  * Use XDG to auto-detect "music_directory" and "db_file".
  + Add tags "AlbumSort", "MUSICBRAINZ_RELEASETRACKID".
  + Disable global Latin-1 fallback for tag values.
  + New resampler option using libsoxr.
  + ARM NEON optimizations.
  + Install systemd unit for socket activation.
- Rebase mpd-sndfile-vorbis.patch and mpd-mpdconf_suse.patch.
- Drop mpd-wavpack.patch and mpd-0.17.4-ffmpeg2.patch as now code
  has been re-written.
- Drop configure options for soup, lastfm and mvp and respective
  build requirements.
- Enable boost and libmpdclient option at configure time and add
  respective build requirements.
- Add libicu-devel to build requirements.
- Disable libwrap configure option as build fails.
- Disable other unused plugins and encoders.
- Clean up spec file for systemd.
* Fri Nov  8 2013 obs@botter.cc
- add Type=forking to mpd.service.
* Fri Sep 20 2013 obs@botter.cc
- Update to 0.17.5:
  * protocol:
  - fix "playlistadd" with URI
  - fix "move" relative to current when there is no current song
  * decoder:
  - ffmpeg: support "application/flv"
  - mikmod: adapt to libmikmod 3.2
  * configure.ac:
  - detect system "ar"
- use gentoo's patch for compiling with ffmpeg 2.x
- add own service file (PM-79)
* Tue Jun 18 2013 fisiu@opensuse.org
- Update to 0.17.4:
  * protocol:
  - allow to omit END in ranges (START:END)
  - don't emit IDLE_PLAYER before audio format is known
  * decoder:
  - ffmpeg: support float planar audio (ffmpeg 1.1)
  - ffmpeg: fix AVFrame allocation
  * player:
  - implement missing "idle" events on output errors
  * clock: fix build failure
* Thu Mar 28 2013 fisiu@opensuse.org
- Update to 0.17.3:
  * output:
  - osx: fix pops during playback
  - recorder: fix I/O error check
  - shout: fix memory leak in error handler
  - recorder, shout: support Ogg packets that span more than one page
  * decoder:
  - ffmpeg: ignore negative time stamps
  - ffmpeg: support planar audio
  * playlist:
  - cue: fix memory leak
  - cue: fix CUE files with only one track
- Drop mpd-systemd_require_network_first.patch: fixed upstream.
* Thu Feb 14 2013 zaitor@opensuse.org
- Add explicit pkgconfig(bzip2) BuildRequires for 12.3 and newer.
* Fri Oct 19 2012 pascal.bleser@opensuse.org
- disable roaraudio support, pulls in ridiculous deps
* Fri Oct 19 2012 pascal.bleser@opensuse.org
- fix systemd unit script to require network to be started prior to
  mpd, thanks to Jean Delvare for the patch
- update to 0.17.2:
  * protocol:
  - fix crash in local file check
  * decoder:
  - fluidsynth: remove throttle (requires libfluidsynth 1.1)
  - fluidsynth: stop playback at end of file
  - fluidsynth: check MIDI file format while scanning
  - fluidsynth: add sample rate setting
  - wavpack: support all APEv2 tags
  * output:
  - httpd: use monotonic clock, avoid hiccups after system clock adjustment
  - httpd: fix throttling bug after resuming playback
  * playlist:
  - cue: map "PERFORMER" to "artist" or "album artist"
  * mapper: fix non-UTF8 music directory name
  * mapper: fix potential crash in file permission check
  * playlist: fix use-after-free bug
  * playlist: fix memory leak
  * state_file: save song priorities
  * player: disable cross-fading in "single" mode
  * update: fix unsafe readlink() usage
- changes from 0.17.1:
  * protocol:
  - require appropriate permissions for searchadd{,pl}
  * tags:
  - aiff: support the AIFC format
  - ape: check for ID3 if no usable APE tag was found
  * playlist:
  - cue: support file types "MP3", "AIFF"
  * output:
  - fix noisy playback with conversion and software volume
* Tue Jul 17 2012 pascal.bleser@opensuse.org
- update to 0.17:
  * protocol:
  - support client-to-client communication
  - "update" and "rescan" need only "CONTROL" permission
  - new command "seekcur" for simpler seeking within current song
  - new command "config" dumps location of music directory
  - add range parameter to command "load"
  - print extra "playlist" object for embedded CUE sheets
  - new commands "searchadd", "searchaddpl"
  * input:
  - cdio_paranoia: new input plugin to play audio CDs
  - curl: enable CURLOPT_NETRC
  - curl: non-blocking I/O
  - soup: new input plugin based on libsoup
  * tags:
  - RVA2: support separate album/track replay gain
  * decoder:
  - mpg123: implement seeking
  - ffmpeg: drop support for pre-0.5 ffmpeg
  - ffmpeg: support WebM
  - oggflac: delete this obsolete plugin
  - dsdiff: new decoder plugin
  * output:
  - alsa: support DSD-over-USB (dCS suggested standard)
  - httpd: support for streaming to a DLNA client
  - openal: improve buffer cancellation
  - shout: add possibility to set url
  - roar: new output plugin for RoarAudio
  * mixer:
  - alsa: listen for external volume changes
  * playlist:
  - allow references to songs outside the music directory
  - new CUE parser, without libcue
  - soundcloud: new plugin for accessing soundcloud.com
  * state_file: add option "restore_paused"
  * cue: show CUE track numbers
  * allow port specification in "bind_to_address" settings
  * support floating point samples
  * systemd socket activation
  * improve --version output
* Sun May  6 2012 fisiu@opensuse.org
- Update to 0.16:8:
  * fix for libsamplerate assertion failure
  * decoder:
  - vorbis (and others): fix seeking at startup
  - ffmpeg: read the "year" tag
  * encoder:
  - vorbis: generate end-of-stream packet before tag
  - vorbis: generate end-of-stream packet when playback ends
  * output:
  - jack: check for connection failure before starting playback
  - jack: workaround for libjack1 crash bug
  - osx: fix stuttering due to buffering bug
  * fix endless loop in text file reader
  * update: skip symlinks in path that is to be updated
- spec-cleaner'ed spec file
* Mon Feb  6 2012 pascal.bleser@opensuse.org
- update to 0.16.7:
  * input:
  - ffmpeg: support libavformat 0.7
  * decoder:
  - ffmpeg: support libavformat 0.8, libavcodec 0.9
  - ffmpeg: support all MPD tags
  * output:
  - httpd: fix excessive buffering
  - openal: force 16 bit playback, as 8 bit doesn't work
  * fix moving after current song
- add mpd-user.conf to doc files, copy to ~/.mpd/mpd.conf for user centric
  setup
- add tcpd and mkisofs support
* Thu Dec 22 2011 detlef@links2linux.de
- new upstream version <0.16.6>
* Sun Oct 23 2011 detlef@links2linux.de
- new upstream version <0.16.5>
* Fri Oct  7 2011 detlef@links2linux.de
- new upstream version <0.16.4>
* Fri Aug  5 2011 detlef@links2linux.de
- new upstream version <0.16.3>
* Thu Mar 24 2011 detlef@links2linux.de
- new upstream version <0.16.2>
* Fri Jan 14 2011 detlef@links2linux.de
- new upstream version <0.16.1>
* Sun Dec 12 2010 detlef@links2linux.de
- new upstream version <0.16>
* Sat Nov 13 2010 detlef@links2linux.de
- new upstream version <0.15.15>
* Wed Oct 13 2010 detlef@links2linux.de
- new upstream version <0.15.13>
  * output_thread: fix race condition after CANCEL command
  * output:
  - httpd: fix random data in stream title
  - httpd: MIME type audio/ogg for Ogg Vorbis
  * input:
  - rewind: update MIME not only once
  - rewind: enable for MMS
* Wed Jul 21 2010 detlef@links2linux.de
- new upstream version <0.15.12>
  * input:
  - curl: remove assertion after curl_multi_fdset()
  * tags:
  - rva2: set "gain", not "peak"
  * decoders:
  - wildmidi: support version 0.2.3
* Fri Jul 16 2010 detlef@links2linux.de
- new upstream version <0.15.11>
  * tags:
  - ape: support album artist
  * decoders:
  - mp4ff: support tags "album artist", "albumartist", "band"
  - mikmod: fix memory leak
  - vorbis: handle uri==NULL
  - ffmpeg: fix memory leak
  - ffmpeg: free AVFormatContext on error
  - ffmpeg: read more metadata
  - ffmpeg: fix libavformat 0.6 by using av_open_input_stream()
  * playlist: emit IDLE_OPTIONS when resetting single mode
  * listen: make get_remote_uid() work on BSD
* Mon May 31 2010 detlef@links2linux.de
- new upstream version <0.15.10>
  * input:
  - mms: fix memory leak in error handler
  - mms: initialize the "eof" attribute
  * decoders:
  - mad: properly calculate ID3 size without libid3tag
* Tue Mar 23 2010 detlef@links2linux.de
- new upstream version <0.15.9>
  * decoders:
  - mad: fix crash when seeking at end of song
  - mpcdec: fix negative shift on fixed-point samples
  - mpcdec: fix replay gain formula with v8
  * playlist: fix single+repeat in random mode
  * player: postpone song tags during cross-fade
* Wed Jan 27 2010 detlef@links2linux.de
- new upstream version <0.15.8>
  * input:
  - curl: allow rewinding with Icy-Metadata
  * decoders:
  - ffmpeg, flac, vorbis: added more flac/vorbis MIME types
  - ffmpeg: enabled libavformat's file name extension detection
  * dbUtils: return empty tag value only if no value was found
  * decoder_thread: fix CUE track playback
  * queue: don't repeat current song in consume mode
* Tue Jan 12 2010 detlef@links2linux.de
- fix init script
* Tue Dec 29 2009 detlef@links2linux.de
- new upstream version <0.15.7>
  * archive:
  - close archive when stream is closed
  - iso, zip: fixed memory leak in destructor
  * input:
  - file: don't fall back to parent directory
  - archive: fixed memory leak in error handler
  * tags:
  - id3: fix ID3v1 charset conversion
  * decoders:
  - eliminate jitter after seek failure
  - ffmpeg: don't try to force stereo
  - wavpack: allow fine-grained seeking
  * mixer: explicitly close all mixers on shutdown
  * mapper: fix memory leak when playlist_directory is not set
  * mapper: apply filesystem_charset to playlists
  * command: verify playlist name in the "rm" command
  * database: return multiple tag values per song
* Fri Nov 20 2009 detlef@links2linux.de
- new upstream version <0.15.6>
  * input:
  - lastfm: fixed variable name in GLib<2.16 code path
  - input/mms: require libmms 0.4
  * archive:
  - zzip: require libzzip 0.13
  * tags:
  - id3: allow 4 MB RIFF/AIFF tags
  * decoders:
  - ffmpeg: convert metadata
  - ffmpeg: align the output buffer
  - oggflac: rewind stream after FLAC detection
  - flac: fixed CUE seeking range check
  - flac: fixed NULL pointer dereference in CUE code
  * output_thread: check again if output is open on PAUSE
  * update: delete ignored symlinks from database
  * database: increased maximum line length to 32 kB
* Wed Oct 21 2009 detlef@links2linux.de
- new upstream version <0.15.5>
  * input:
  - curl: don't abort if a packet has only metadata
  - curl: fixed endless loop during buffering
  * tags:
  - riff, aiff: fixed "limited range" gcc warning
  * decoders:
  - flac: fixed two memory leaks in the CUE tag loader
  * decoder_thread: change the fallback decoder name to "mad"
  * output_thread: check again if output is open on CANCEL
  * update: fixed memory leak during container scan
* Tue Sep  1 2009 detlef@links2linux.de
- new upstream version <0.15.3>
  * Document nextsong and nextsongid
  * update: don't re-read unchanged container files
  * output_init: initialize the "pause" flag
  * decoder/vorbis: faster tag scanning with ov_test_callback()
* Tue Aug 18 2009 detlef@links2linux.de
- new upstream version <0.15.2>
  * tags:
  - ape: check the tag size (fixes integer underflow)
  - ape: added protection against large memory allocations
  * decoders:
  - mad: skip ID3 frames when libid3tag is disabled
  - flac: parse all replaygain tags
  - flac: don't allocate cuesheet twice (memleak)
  * output:
  - shout: fixed stuck pause bug
  - shout: minimize the unpause latency
  * update: free empty path string (memleak)
  * update: free temporary string in container scan (memleak)
  * directory: free empty directories after removing them (memleak)
* Sat Jul 18 2009 detlef@links2linux.de
- new upstream version <0.15.1>
* Sat Feb 14 2009 detlef@links2linux.de
- new upstream version <0.14.2>
  * Modify version string to post-release version 0.14.2~git
  * mpd version 0.14.2
  * ffmeg: added support for the tags comment, genre, year
  * mikmod: call MikMod_Exit() only in the finish() method
  * jack: register ports before activating clients
  * jack: allocate ring buffers before connecting
  * jack: clear "shutdown" flag on reconnect
  * jack: reduced sleep time to 1ms
  * mapper: remove trailing slashes from music_directory
  * mapper: ignore duplicate slashes in playlists
  * wavpack: pass NULL if the .wvc file fails to open
  * player_thread: set player error when output device fails
  * shout_mp3: free the lame_data struct on exit
  * shout_mp3: call lame_close() in clear_encoder() method
  * ffmpeg: print codec name
  * ffmpeg: don't warn of empty packet output
  * ffmpeg: check if the time stamp is valid
  * ffmpeg: fixed seek integer overflow
  * shout: removed shout_data.shout_error
  * shout: removed shout_data.tag_to_send
  * shout: switch to blocking mode
  * shout: use libshout's synchronization
  * shout: don't postpone metadata
  * shout: clear buffer before calling the encoder
  * configure.ac: define HAVE_FFMPEG after all checks
  * ffmpeg: added TTA support
  * aac: fix stream metadata
  * update: recursively purge deleted directories
  * update: free deleted subdirectories
  * ffmpeg: enable WAV streaming
* Mon Jan 19 2009 detlef@links2linux.de
- new upstream version <0.14.1>
  * decoders:
  - mp4: support the writer/composer tag
  - id3: strip leading and trailing whitespace from ID3 tags
  - oggvorbis: fix tremor support
  - oggvorbis: disable seeking on remote files
  * audio outputs:
  - jack: allocate default port names (fixes a crash)
  * update:
  - refresh stats after update
  - save the database even if it is empty
  * input_curl:
  - use select() to eliminate busy loop during connect
  - honour http_proxy_* config directives
  - fix assertion failure on "connection refused"
  - fix assertion failure with empty HTTP responses
  * corrected the sample calculation in the fallback resampler
  * log: automatically append newline
  * fix setenv() conflict on Solaris
  * configure.ac: check for pkg-config before using it
  * fix minor memory leak in decoder_tag()
  * fix cross-fading bug: it used to play some chunks of the new song twice
  * playlist
  - fix assertion failure during playlist load
  - implement Fisher-Yates shuffle properly
  - safely search the playlist for deleted song
  * use custom PRNG for volume dithering (speedup)
  * detect libid3tag without pkg-config
* Sat Dec 27 2008 detlef@links2linux.de
- new upstream version <0.14>
* Fri Jun 20 2008 detlef@links2linux.de
- new upstream version <0.13.2>
* Wed Jan 30 2008 detlef@links2linux.de
- new upstream version <0.13.1>
* Fri Jul 13 2007 detlef@links2linux.de
- add BuildRequires: libmikmod
- add BuildRequires: libmikmod-devel for > 1020
* Tue May 29 2007 detlef@links2linux.de
- new upstream version <0.13.0>
* Mon Mar 26 2007 detlef@links2linux.de
- new upstream version
* Mon Nov 13 2006 detlef@links2linux.de
- no resmgr for 10.2, use group audio
* Fri Oct 13 2006 detlef@links2linux.de
- new upstream version
* Thu Sep 28 2006 detlef@links2linux.de
- new upstream version
* Mon Sep 25 2006 detlef@links2linux.de
- new upstream version
* Sat Sep  2 2006 detlef@links2linux.de
- new upstream version
* Sun Aug 20 2006 detlef@links2linux.de
- new upstream version
* Fri Aug 11 2006 detlef@links2linux.de
- new upstream version
* Fri Jul 28 2006 detlef@links2linux.de
- new SVN-Snapshot
* Mon Dec  5 2005 malakhanov@gmx.de
- finally force mpd to work with resmgr
* Mon Jul 11 2005 malakhanov@gmx.de
- modified for x64 build
* Mon Mar 22 2004 malakhanov@gmx.de
- modified for SUSE/Packman. Init script courtesy of  Davide Lucchesi <odiobill@despammed.com>, 2003
* Wed Mar 10 2004 gbpeck@sbcglobal.net
- Rebuild for official release
* Mon Mar  8 2004 gbpeck@sbcglobal.net
- Version 0.10.1
* Wed Mar  3 2004 gbpeck@sbcglobal.net
- Version 0.10.0
- Add audiofile-devel builddep (for wav support)
- Add AUTHORS to docs
* Fri Feb  6 2004 gbpeck@sbcglobal.net
- Rebuild with mach
* Wed Jan 21 2004 gbpeck@sbcglobal.net
- Version 0.9.4
* Thu Oct 30 2003 gbpeck@sbcglobal.net
- Version 0.9.3
* Tue Oct  7 2003 gbpeck@sbcglobal.net
- Version 0.9.2
* Tue Sep 30 2003 gbpeck@sbcglobal.net
- Version 0.9.1
- Add BuildRequires on alsa-lib-devel
- Add versioned Requires on libao and libao-devel (from the debian
  control file)
* Thu Sep  4 2003 gbpeck@sbcglobal.net
- Version 0.8.7
* Mon Aug 18 2003 gbpeck@sbcglobal.net
- Version 0.8.5
* Thu Aug 14 2003 gbpeck@sbcglobal.net
- Initial build
